/*
 * Copyright (c) 2001-2014,FineReport Inc, All Rights Reserved.
 */

;(function($){
    /**
     * 下拉复选框控件
     *
     *     @example
     *     var $root = $('<div>').css({position : 'absolute', top : 5, left : 40}).appendTo('body');
     *     var editor = new FR.NewCheckBoxEditor({
     *           renderEl : $root,
     *           directEdit : true,
     *           allowBlank : true,
     *           widgetUrl : null,         //同下拉框
     *           returnArray : true,      //返回值是否以数组形式
     *           delimiter : ',',             //字符串返回值的分隔符
     *           startSymbol : '',          //起始符
     *           endSymbol : '',           //结束符
     *           fontSize : 14,
     *           width : 120,
     *           height : 24,
     *           maxCount : 10,
     *           items : [
     *               {text : "111", value : "aaa"},
     *               {text : "222", value : "bbb"},
     *               {text : "333", value : "ccc"},
     *               {text : "444", value : "ddd"}
     *           ]
     *      });
     *
     * @class FR.NewCheckBoxEditor
     * @extends FR.CheckBoxEditor
     *
     * @cfg {JSON} options 属性配置
     * @cfg {String} [options.delimiter=','] 结果分隔符
     * @cfg {String} [options.startSymbol=''] 起始符
     * @cfg {String} [options.endSymbol=''] 结束符
     */
    FR.NewCheckBoxEditor = FR.extend(FR.CheckBoxEditor, /**@class FR.NewCheckBoxEditor*/{
        _ajaxSearch: function () {
            this.embellishView();
            this.$view.empty();
            this.$view.height(30);
            FR.HtmlLoader.loadingMoreData({
                el : this.$view,
                show : true
            });
            this.modifyPosition();
            this.$view.show();
            var para = this.allPara.apply(this, arguments);
            this.options.searchData.resetStatus(para);
            var self = this;
            var searchTimes = self.lastAjaxSearchTimes ? (self.lastAjaxSearchTimes + 1) : 1;
            self.lastAjaxSearchTimes = searchTimes;
            this.options.searchData.loadObject(function (data) {
                if (searchTimes < self.lastAjaxSearchTimes) {
                    return;
                }
                self.options.data.setData(para, data);
                self.checkViewScroll(self.options.data.getData());
                self._setItems(self.options.data.getData());
                FR.HtmlLoader.loadingMoreData({
                    el : self.$view
                });
                self.$view.hide();
                self.options.need2BuildList = false;
                self._createVieList();
                self.__makeSureInputValueInResList();
                if (self.options.data.getData().length > 0) {
                    self.setFocusWithIndex(0);
                    $.each(self.ck_el_array, function (idx, it) {
                        it.setSelectedWithoutEvent(false);
                    });
                    self.innerCheckBox.selected(false);
                    self.inAllSelectModel = false;
                    self.text = [];
                    self.fireEvent(FR.Events.AFTEREDIT);
                }
            });
        },
        /**
         * 生成下拉触发按钮组件
         * @private
         */
        _createTriggerBtn: function () {
            var self = this;
            var triggerFn = this.onTriggerClick.createDelegate(this);

            this.btn = $("<div/>").addClass(self.options.btn_up)
                .appendTo(this.element);
            var M = {
                onMouSeenter: function (e) {
                    if (!self.options.disabled) {
                        self.btn.switchClass(self.options.btn_over);
                    }
                },
                onMouseLeave: function (e) {
                    if (!self.options.disabled) {
                        self.btn.switchClass(self.options.btn_up);
                    }
                },
                onMouseDown: function (e) {
                    if (!self.options.disabled) {
                        self.btn.switchClass(self.options.btn_down);
                        triggerFn();
                    }
                },
                onMouseUp: function (e) {
                    if (!self.options.disabled) {
                        self.btn.switchClass(self.options.btn_over);
                    }
                }
            };
            this.btn.mouseenter(M.onMouSeenter).mouseleave(M.onMouseLeave)
                .mouseup(M.onMouseUp).mousedown(M.onMouseDown);
        }
    });
    $.shortcut("newcombocheckbox", FR.NewCheckBoxEditor);
})(jQuery);